@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: data.c 1694 2010-05-25 01:55:58Z beerli $
+$Id: data.c 1712 2010-08-20 04:17:16Z beerli $
 
 -----------------------------------
 add this to the microsatellite data, this will allow to use
@@ -72,7 +72,7 @@ extern void jumble (long *s, long n);
 /*private functions */
 //void init_data_structure1 (data_fmt ** data, option_fmt * options);
 void read_header (FILE * infile, data_fmt * data, option_fmt * options);
-void read_sites (data_fmt * data, world_fmt *world);
+void read_sites (data_fmt * data, world_fmt *world, option_fmt *options);
 //void init_data_structure2 (data_fmt ** data, option_fmt * options, long pop);
 //void init_data_structure3 (data_fmt * data);
 void read_popheader (FILE * infile, data_fmt * data, option_fmt * options, long pop, long genomes);
@@ -295,7 +295,7 @@ get_new_data (FILE * infile, data_fmt * data, option_fmt * options, world_fmt *w
   //
   // this will set up all the locus structure, but may need some additional
   // init_data-structure1a()
-  read_sites(data, world);
+  read_sites(data, world, options);
   // snps etc need something like
   //        data->seq[0]->addon = 4;
   // hapmap data is peculiar check that
@@ -373,10 +373,10 @@ get_data (FILE * infile, data_fmt * data, option_fmt * options, world_fmt *world
     {
     case 's':
     case 'f':// read standard sequence data
-      read_sites (data,world);
+      read_sites (data,world, options);
         break;
     case 'n': // read snp data
-      read_sites (data,world);
+      read_sites (data,world, options);
         data->seq[0]->addon = 4;
         break;
     case 'h': //read data from hapmap allele frequency files
@@ -386,12 +386,13 @@ get_data (FILE * infile, data_fmt * data, option_fmt * options, world_fmt *world
       data->seq[0]->addon = 4;
         break;
     case 'u': // read unlinked snp
-      read_sites (data,world);
+      read_sites (data,world, options);
         data->seq[0]->addon = 4;
         break;
     default:
-        data->seq[0]->fracchange = 1.0;
-        break;
+      read_sites(data,world, options); // checks whether there is a line for microsat repeat numbers
+      data->seq[0]->fracchange = 1.0;
+      break;
     }
     if (options->progress)
         fprintf (stdout, "\n\n");
@@ -744,7 +745,7 @@ void set_datatype(char input, long locus, char ** locitypes, long *alloc)
 /// for the datatype=h it is assumed that all loci are the same and of type n
 /// plain numbers are considered to be sequence loci with no name
 void
-read_sites (data_fmt * data, world_fmt *world)
+read_sites (data_fmt * data, world_fmt *world, option_fmt *options)
 {
   char * val=NULL;
   boolean linked=TRUE;
@@ -755,15 +756,56 @@ read_sites (data_fmt * data, world_fmt *world)
     long zz=0; //zz is used for mutationmodels and is not reset at closing ')'
     input = (char *) mycalloc(LONGLINESIZE ,sizeof(char));
     word = (char *) mycalloc(LONGLINESIZE ,sizeof(char));
+    // check whether the microsats are not repeats but fragmentlength  
+    data->has_repeats = TRUE;
     for (locus = 0; locus < data->loci; locus++)
     {
       read_word(data->infile, input);
       switch(input[0])
 	{
 	case  '#':
-	  FGETS(input,LINESIZE,data->infile);
-	  locus--;
-	  continue;
+	  if(input[1]=='@')
+	    {
+	      // line is microsatellite instruction
+	      if(input[2]=='M')
+		{
+		  FGETS(input,LINESIZE,data->infile); // read the line 
+		  locus--;
+		  long oldi=0;
+		  long i;
+		  long len=0;
+		  data->has_repeats = FALSE;
+		  for(i = 0 ; i < data->loci; i++)
+		    {
+		      memset(word,'0', sizeof(char)*LINESIZE);
+		      len += read_word_delim(input+len,word," ;,\t");
+		      if(word[0]!='\0')
+			{
+			  data->repeatlength[i] = atol(word);
+			  oldi=i;
+			}
+		      else
+			{
+			  data->repeatlength[i] = data->repeatlength[oldi];
+			}
+		    }
+		}
+	      else
+		{
+		  FGETS(input,LINESIZE,data->infile); // read the line 
+		  locus--;
+		}
+	      myfree(input);
+	      myfree(word);
+	      return;
+	    }
+	  else
+	    {
+	      // line is a comment
+	      FGETS(input,LINESIZE,data->infile); // read the line 
+	      locus--;
+	      continue;
+	    }
 	  break;
 	  
 	  case '(':
@@ -822,6 +864,13 @@ read_sites (data_fmt * data, world_fmt *world)
 	    z=0; // reset subloci for the next locus
 	    break;
 	  default:
+	    if (!strchr (SEQUENCETYPES, options->datatype))
+	      {
+                unread_word(data->infile, input);
+		myfree(input);
+		myfree(word);
+		return;
+	      }
 	    if(isalpha(input[0]))
 	      {
 		read_word_delim(input,word,"=");
@@ -1220,14 +1269,19 @@ long check_list(long la1, long nla1, long locus, data_fmt *data)
 
 void len2repeat(char *a1, long rlen, long locus, data_fmt *data)
 {
-  long la1 = (long) a1;
+  long la1 = (long) atol(a1);
   long a=0;
   if((a=la1 % rlen) != 0)
     {
       long correction = (((((float) rlen) / 2.) < a) ? (-a) : (rlen/2 == a ? (UNIF_RANDUM()<0.5 ? -a : a) : (rlen - a))); 
-      long nla = check_list(la1,la1+correction, locus, data);
+      //long nla = check_list(la1,la1+correction, locus, data);
+      long nla = (la1+correction)/rlen;
       sprintf(a1,"%li",nla);
     }
+  else
+    {
+      sprintf(a1,"%li",la1/rlen);
+    }
 }
 
 
@@ -1335,6 +1389,13 @@ read_alleles (FILE * infile, data_fmt * data, long pop, long ind)
     myfree(isave);
 }
 
+#ifdef WINDOWS
+long lround(double d)
+{
+  return floor( d+0.5 );
+}
+#endif
+
 void
 read_hapmap (FILE * infile, data_fmt * data, option_fmt * options,
               long locus, long pop)
@@ -1726,6 +1787,11 @@ print_data_summary (FILE * file, world_fmt * world, option_fmt * options,
     }
   fprintf (file, "Data file:             %s\n", options->infilename);
   fprintf (file, "Datatype:              %20s\n", dstring);
+  if(!data->has_repeats)
+    {
+      fprintf (file, "[Fragment length is translated to repeats]\n");
+    }
+
   fprintf (file, "Number of loci:        %20li\n\n",
 	   data->loci);
   if(options->has_datefile)
@@ -1769,13 +1835,15 @@ print_data_summary (FILE * file, world_fmt * world, option_fmt * options,
 	    {
 	      nummiss = find_missing(data,pop,locus);
 	      numind = data->numalleles[pop][locus] - nummiss;
-	      fprintf (file, "%3li %-*.*s %5li %6li (%li)\n", options->newpops[pop], maxlength,maxlength,(locus==0 ? data->popnames[pop] : " " ), locus+1 , numind, nummiss);
+	      fprintf (file, "%3li %-*.*s %5li %6li (%li)\n", options->newpops[pop], maxlength, maxlength,
+		       (locus==0 ? data->popnames[pop] : " " ), locus+1 , numind, nummiss);
 	    }
 	  else
 	    {
 	      nummiss = 0;
 	      numind = data->numind[pop][locus];
-	      fprintf (file, "%3li %-*.*s %5li    %6li\n", options->newpops[pop], maxlength,maxlength,(locus==0 ? data->popnames[pop] : " "), locus+1 , numind);
+	      fprintf (file, "%3li %-*.*s %5li    %6li\n", options->newpops[pop], maxlength, maxlength,
+		       (locus==0 ? data->popnames[pop] : " "), locus+1 , numind);
 	    }
 	  total[locus] += numind;
 	  totalmiss[locus] += nummiss;
@@ -1785,14 +1853,16 @@ print_data_summary (FILE * file, world_fmt * world, option_fmt * options,
       {
         for(locus=0; locus< data->loci; locus++)
 	  {
-	    fprintf (file,"    %-*.*s %5li %6li (%li)\n",maxlength,maxlength, (locus == 0 ? "Total of all populations" : " "), locus+1, total[locus], totalmiss[locus]);
+	    fprintf (file,"    %-*.*s %5li %6li (%li)\n",maxlength,maxlength, 
+		     (locus == 0 ? "Total of all populations" : " "), locus+1, total[locus], totalmiss[locus]);
 	  }
       }
     else
       {
         for(locus=0; locus< data->loci; locus++)
 	  {
-	    fprintf (file,"    %-*.*s %5li    %6li\n",maxlength,maxlength, (locus == 0 ? "Total of all populations" : " "), locus+1, total[locus]);
+	    fprintf (file,"    %-*.*s %5li    %6li\n",maxlength,maxlength, 
+		     (locus == 0 ? "Total of all populations" : " "), locus+1, total[locus]);
 	  }
       }    
     fprintf(file,"\n");
