@@ -45,6 +45,9 @@ void read_from_bayesmdim_minimal_info(FILE *mdimfile, world_fmt *world,option_fm
 	  printf("%i> replicate    = %li\n",myID, tmp);
 	  printf("%i> replicatenum = %li\n",myID, options->replicatenum);
 	  printf("%i> use_M        = %li\n",myID, (long) recordedusem);
+	  // fill some more...
+	  data->numpop = world->numpop;
+	  options->newpops_numpop = world->numpop;
 	  nrep = options->replicatenum;
 	  if (nrep == 0)
 	    nrep = 1;
@@ -264,7 +267,8 @@ void read_bayes_fromfile(FILE *mdimfile, world_fmt *world,option_fmt *options)
 	      // harmonic mean: scaler contains the log value, hm contains 1.
 	      world->hmscale[locus] = atof(strsep(&inptr,"\t"));
 	      world->hm[locus] = 1.; 
-	      calculate_ess_frombayes (world, step, params, locus, &autocorrelation[locus*nn], &ess[locus*nn]);
+	      //	      calculate_ess_frombayes (world, step, params, locus, &autocorrelation[locus*nn], &ess[locus*nn]);
+	      calculate_ess_frombayes (world, step, params, locus, autocorrelation, ess);
 	    }
 #endif
 	}
