@@ -26,7 +26,7 @@
 *   works and am not responsible for any damage you may cause or have.
 *
 */
-/* $Id: main.c 1694 2010-05-25 01:55:58Z beerli $*/
+/* $Id: main.c 1713 2010-09-05 03:16:27Z beerli $*/
 
 #include "migration.h"
 #include "sighandler.h"
@@ -237,8 +237,8 @@ prepare_next_chain (world_fmt ** universe, worldoption_fmt * options,
                     long *pluschain, long locus, long replicate);
 
 void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options);
-
-#ifdef MPI /* */
+#ifdef MPI
+void fix_bayesfactor(world_fmt *world, option_fmt * options);
 void      print_marginal_like(float *temp, long *z, world_fmt * world);
 #else /*not MPI*/
 void      print_marginal_like(char *temp, long *c, world_fmt * world);
@@ -565,13 +565,16 @@ main (int argc, char **argv)
     if (myID == MASTER)
       {
 #endif
-#ifdef BFDEBUG	
+	//#ifdef BFDEBUG	
 	if(EARTH->options->bayes_infer)
-#else
-	if(EARTH->options->bayes_infer  && options->datatype!='g')
-#endif
+	//#else
+	//if(EARTH->options->bayes_infer  && options->datatype!='g')
+	  //#endif
 	  {
 	// print marginal likelihoods
+#ifdef MPI
+	    fix_bayesfactor(EARTH,options);
+#endif
 	    print_bayesfactor(EARTH->outfile, universe,options);
 	// printing of MCMC run characteristics
 	    fprintf(EARTH->outfile,"MCMC run characteristics\n");
@@ -843,6 +846,22 @@ long  calculate_newpop_numpop(option_fmt *options, data_fmt *data)
   return newnumpop;
 }
 
+
+///
+/// the slice sampling stick size is allocated here for the options, this is 
+/// done in three different places for: standard, genealogy, MPI
+void alloc_sticksize(option_fmt *options, data_fmt *data)
+{
+  if( options->slice_sticksizes==NULL)
+    {
+      options->slice_sticksizes = (MYREAL *) mycalloc(data->numpop * data->numpop + 1, sizeof(MYREAL));
+    }
+  else
+    {
+      options->slice_sticksizes = (MYREAL *) myrealloc(options->slice_sticksizes, (data->numpop * data->numpop + 1)* sizeof(MYREAL));
+    }
+}
+
 ///
 /// runs the MCMC sampling 
 void
@@ -888,10 +907,11 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
 #endif
   set_plot (options);
   EARTH->cold = TRUE; // this is the cold chain when we use heating, the hotter chains have FALSE
-  options->slice_sticksizes = (MYREAL *) mycalloc(data->numpop * data->numpop + 1, sizeof(MYREAL));
-  // init of options->slice_sticksizes
+  // sticksizes are filled in init_world but initialized here so make sure that 
+  // the heated chains do not produce a memory leak by mutiply initializing the sticksizes
+  alloc_sticksize(options,data);
+  // filling of options->slice_sticksizes
   // deferred after world->bayes initialization in init_world() 
-
   calculate_newpop_numpop(options,data);
 
   init_world (EARTH, data, options);
@@ -1172,8 +1192,8 @@ heated_swap (world_fmt ** universe, worldoption_fmt * options)
     long sm = 0, mv = 0, vw = 0;
     long r;
     //debug for heating traverse issues
-    //
-    //return;
+    if(options->heatedswap_off || (options->heating_count++ % options->heating_interval) != 0)
+      return;
     switch (r = RANDINT (0, options->heated_chains - 2))
     {
         case 2:
@@ -1447,12 +1467,24 @@ boolean analyze_oldbayesdata(world_fmt *world, option_fmt *options, data_fmt *da
       warning("does not work correctly yet");
       read_from_bayesmdim_minimal_info(world->bayesmdimfile, world, options, data);
       read_geofile (data, options, world->numpop);
+      alloc_sticksize(options,data);
+      options->newpops_numalloc = world->numpop;
+      options->newpops = (long*) mycalloc(options->newpops_numalloc, sizeof(long));
+      long pop;
+      for(pop=0;pop<world->numpop;pop++)
+	options->newpops[pop]=pop+1;
       init_world (world, data, options);
       read_bayes_fromfile(world->bayesmdimfile, world, options);
     }
 #else
   read_from_bayesmdim_minimal_info(world->bayesmdimfile, world, options, data);
   read_geofile (data, options, world->numpop);
+  alloc_sticksize(options,data);
+  options->newpops_numalloc = world->numpop;
+  options->newpops = (long*) mycalloc(options->newpops_numalloc, sizeof(long));
+  long pop;
+  for(pop=0;pop<world->numpop;pop++)
+    options->newpops[pop]=pop+1;
   init_world (world, data, options);
   read_bayes_fromfile(world->bayesmdimfile, world, options);
 #endif
@@ -1532,14 +1564,15 @@ profile_tables (option_fmt * options, world_fmt * world, long *gmaxptr)
 	  }   
         for (i = 0; i < len; i++)
 	  {
-            (void) print_profile_likelihood_driver (i, world, gmaxptr);
+            boolean success =  print_profile_likelihood_driver (i, world, gmaxptr);
 	    if(options->profile == TABLES || options->profile == ALL)
 	      {
 		FPRINTF (world->outfile, "%s\n\n", world->buffer);
 		//ascii_print_profile_table(options->profilemethod, world);
 #ifdef PRETTY
 		location = strlen(world->buffer);
-		pdf_print_profile_table(55., &page_height, options->profilemethod, world->buffer + location + 1, world);
+		if(success)
+		  pdf_print_profile_table(55., &page_height, options->profilemethod, world->buffer + location + 1, world);
 #endif 
 	      }
             world->buffer[0] = '\0';
@@ -2257,7 +2290,8 @@ run_chains (world_fmt ** universe,
 	  }
         if (EARTH->options->heating)
 	  {
-            print_heating_progress (universe, EARTH->options, EARTH->options->heating_interval * increment * steps * treeupdateratio);
+	    //            print_heating_progress (universe, EARTH->options, EARTH->options->heating_interval * increment * steps * treeupdateratio);
+            print_heating_progress (universe, EARTH->options, increment * steps * treeupdateratio);
 	    reset_heated_accept(universe,EARTH->options->heated_chains);
 	  }
         else
@@ -2461,6 +2495,55 @@ MYREAL combine_scaling_factor(world_fmt *world)
   return scaling_factor;
 }
 
+void print_bf_values(world_fmt * world)
+{
+  long locus;
+  const long hc = world->options->heated_chains;
+  for(locus=0;locus<world->loci;locus++)
+    {
+      if(world->data->skiploci[locus])
+	continue;
+      printf("=====> locus=%li ",locus );
+      long t;
+      for(t=0; t < hc; t++)
+	{
+	  printf("%f ",world->bf[locus*hc+t]);
+	}
+      printf("\n");
+    }
+}
+
+#ifdef MPI
+void fix_bayesfactor(world_fmt *world, option_fmt * options)
+{
+  return;
+  long locus;
+  long t;
+  const long hc = world->options->heated_chains;
+  const long maxreplicate = (options->replicate
+		       && options->replicatenum >
+		       0) ? options->replicatenum : 1;
+  if(options->heating)//-----------------------heating
+    {
+      for(locus=0;locus<world->loci;locus++)
+	{
+	  if(world->data->skiploci[locus])
+	    continue;
+	  // the thermodynamic integration is reporting maxreplicate times too high values
+	  // warning("this should fix the thermodynamic/mpi/replicate  problem, but needs to be checked for multilocus data");
+	  printf("@@@@@@@ locus=%li %li (%f) ",locus,maxreplicate, world->bf[locus * hc + 0] );
+	  for(t=0; t < hc; t++)
+	    {
+	      world->bf[locus * hc + t] /= maxreplicate;
+	      printf("%f ",world->bf[locus*hc+t]);
+	    }
+	  printf("\n");
+	}
+    }
+}
+#endif
+
+
 void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 {
 #ifdef MPI
@@ -2518,18 +2601,6 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 	  
 	  lsum = 0.;
 	  lsum0 = 0.;
-#ifdef MPI
-	  // the thermodynamic integration is reporting maxreplicate times too high values
-	  // warning("this should fix the thermodynamic/mpi/replicate  problem, but needs to be checked for multilocus data");
-	  //	  if(!done)
-	  //  {
-	  for(t=0; t < hc; t++)
-	    {
-	      //TEST	      EARTH->bf[locus * hc + t] /= maxreplicate;
-	    }
-	  //      done=TRUE;
-	  //  }
-#endif
 	  // from very hot to cold, the 
 	  for(t=1; t < hc; t++)
 	    {
@@ -2775,6 +2846,7 @@ void calculate_BF(world_fmt **universe, option_fmt *options)
 	    fprintf(universe[0]->options->mixfile," @T %10.10f %10.10f", universe[i]->heat, xx);
 #endif
 	  EARTH->bf[locus * hc + i] += (xx - EARTH->bf[locus * hc + i])/ (EARTH->am[locus]);
+	  //EARTH->bf[locus * hc + i] += (xx - EARTH->bf[locus * hc + i]);
 	  //#ifdef THERMOCHECK
 	  //fprintf(universe[0]->options->mixfile,"%f\n", 	  EARTH->bf[locus * hc + i]);
 	  //#endif
