@@ -18,7 +18,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: mcmc1.c 1665 2010-03-21 20:28:10Z beerli $
+$Id: mcmc1.c 1691 2010-05-14 14:26:56Z beerli $
 -------------------------------------------------------*/
 /* \file mcmc1.c
 
@@ -746,7 +746,8 @@ void traverse_tagnew(node *theNode, node *origin)
 void
 chooseOrigin (proposal_fmt * proposal)
 {
-    long elem = 0, oldelem = (proposal->sumtips * 2.);
+  long elem = 0;
+  // oldelem = (proposal->sumtips * 2.);
     node *tmp=NULL, **goal;
     //032110 goal = (node **) mycalloc (oldelem, sizeof (node *));
     //#ifdef DEBUG
