@@ -16,7 +16,7 @@
  
   Copyright 2002 Peter Beerli and Joseph Felsenstein, Seattle WA
   Copyright 2003 Peter Beerli, Tallahassee FL
-  $Id: migration.h 1683 2010-05-06 04:05:30Z beerli $
+  $Id: migration.h 1711 2010-08-13 19:42:33Z beerli $
   *----------------------------------------------------------------
 */
 /**
@@ -278,6 +278,7 @@ typedef struct _data
   long *numrepeatnumbers;
   long **repeatnumbers;
   long *repeatlength;
+  boolean has_repeats;
 }
 data_fmt;
 
@@ -593,7 +594,7 @@ typedef struct _option
   long numtimings; // number of elements in the timings vector
   MYREAL **timemodifiers; // vector of parameter modifier vectors
 #endif
-
+  boolean heatedswap_off;
 }
 option_fmt;
 
@@ -885,6 +886,7 @@ typedef struct _worldoption
     short heating;
     long heated_chains;
     long heating_interval;
+  long heating_count;
     boolean adaptiveheat;
     char profilemethod;
     boolean printprofile;
@@ -951,6 +953,7 @@ typedef struct _worldoption
   long mutationrate_year_numalloc; // 
   MYREAL generation_year;
   boolean treeinmemory;
+  boolean heatedswap_off;
 }
 worldoption_fmt;
 
@@ -1175,6 +1178,10 @@ typedef struct _world
   long *sublocistarts;//per locus
   long *maxnumpattern;//per locus
   mutationmodel_fmt *mutationmodels;
+  //
+  float page_width;
+  float page_height;
+  //
 #ifdef BEAGLE
   beagle_fmt *beagle;
 #endif
