@@ -16,7 +16,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: reporter.c 1701 2010-06-13 21:00:45Z beerli $
+$Id: reporter.c 1716 2010-09-07 20:33:27Z beerli $
  
 -------------------------------------------------------*/
 /* \file reporter.c 
@@ -630,9 +630,9 @@ void calculate_ess_frombayes(world_fmt *world, long T, MYREAL *params, long locu
   if(T==0)
     return;
 
-  delta = (double *) mycalloc(nnbase,sizeof(double));
+  delta = (double *) mycalloc(nn,sizeof(double));
   //handles BAYES or ML
- start = (world->options->bayes_infer ? 0 : world->numpop2);
+  start = (world->options->bayes_infer ? 0 : world->numpop2);
   if(n[locus]==0) //initialization of mean calculator
     {
       n[locus] += 1;
@@ -668,8 +668,6 @@ void calculate_ess_frombayes(world_fmt *world, long T, MYREAL *params, long locu
 	  xstart[z] = x;
 	  xold[z] = x;
 	}
-      //  v = 0.0;
-      myfree(delta);
     }
   else
     {
@@ -716,8 +714,8 @@ void calculate_ess_frombayes(world_fmt *world, long T, MYREAL *params, long locu
 	  //printf("[%li] n=%li effsample=%g atoc=%g r=%g (%f) s=%g mean=%g\n", j, n[locus],effsample[j],autoc[j],r[j], temp, S[j],mean[j]);
 	  xold[z] = x;
 	}
-      myfree(delta);
     }
+  myfree(delta);    
   //  *variance =  (MYREAL) v[locus] / n[locus];
   //return *variance;
 }
