@@ -20,7 +20,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c 1683 2010-05-06 04:05:30Z beerli $
+$Id: tools.c 1712 2010-08-20 04:17:16Z beerli $
 -------------------------------------------------------*/
 /* \file tools.c */
 
@@ -1022,18 +1022,20 @@ void remove_trailing_blanks(char **filename)
 long read_word_delim(char *input, char *word, char * delim)
 {
   long i = 1;
-    int ch;
-    long count = 0;
-    ch = input[0];
-    while (isspace (ch))
-        ch = input[i++];
-    while(strchr(delim, ch)==NULL)
+  int ch;
+  long count = 0;
+  ch = input[0];
+  if(ch=='\0')
+    return 0;
+  while (isspace (ch))
+    ch = input[i++];
+  while(strchr(delim, ch)==NULL)
     {
-        word[count++] = ch;
-        ch = input[i++];
+      word[count++] = ch;
+      ch = input[i++];
     }
-    word[count]='\0';
-    return i;
+  word[count]='\0';
+  return i;
 }
 ///
 /// read a single word from a file
@@ -3279,12 +3281,12 @@ void add_to_buffer(char *fp, long *bufsize, char **buffer, long *allocbufsize)
 
 
 /// sticks a text into the printing buffer
-long print_to_buffer(char **buffer, long *maxbufsize, long *pos, const char *fmt, ...)
+long print_to_buffer(char **buffer, long *maxbufsize, char *tempbuffer, long *pos, const char *fmt, ...)
 {
   long mypos=0;
-  char *p;
+  char *p = tempbuffer;
   va_list ap;
-  p = (char *) mycalloc(MAXBUFSIZE,sizeof(char));
+  //p = (char *) mycalloc(1024,sizeof(char));
   va_start(ap, fmt);
   mypos = vsprintf(p, fmt, ap);
   va_end(ap);
@@ -3302,8 +3304,8 @@ long print_to_buffer(char **buffer, long *maxbufsize, long *pos, const char *fmt
 	(*buffer) = (char *) myrealloc ((*buffer), (*maxbufsize) * sizeof (char));
 	(*pos) += sprintf((*buffer) + (*pos), "%s",p);
       }
-    myfree(p);
-    return (*pos);
+  //  myfree(p);
+  return (*pos);
 }
 
 
