@@ -14,7 +14,7 @@
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2006 Peter Beerli, Tallahassee FL
  
-$Id: tools.h 1514 2009-05-06 20:34:50Z beerli $
+$Id: tools.h 1712 2010-08-20 04:17:16Z beerli $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -75,9 +75,11 @@ extern void doublevec1d (MYREAL **v, long size);
 extern void doublevec2d (MYREAL ***v, long size1, long size2);
 extern void floatvec2d (float ***v, long size1, long size2);
 extern void charvec2d (char ***v, long size1, long size2);
+extern void intvec2d (long ***v, long size1, long size2);
 extern void free_doublevec2d (MYREAL **v);
 extern void free_floatvec2d (float **v);
 extern void free_charvec2d (char **v);
+extern void free_intvec2d (long **v);
 extern void setdoublevec1d (MYREAL **v, MYREAL *w, long size);
 extern void add_vector (MYREAL *result, MYREAL *v, long size);
 
@@ -99,7 +101,7 @@ extern long count_words (char *text);
 extern void read_word(FILE *infile, char *word);
 extern void unread_word(FILE *infile, char *word);
 extern void add_to_buffer(char *fp, long *bufsize, char **buffer, long *allocbufsize);
-extern long print_to_buffer(char **buffer, long *maxbufsize, long *pos, const char *fmt, ...);
+extern long print_to_buffer(char **buffer, long *maxbufsize, char *tempbuffer, long *pos, const char *fmt, ...);
 extern void remove_trailing_blanks(char **filename);
 
 /* time reporting */
